pub trait Hashable {
// Required method
fn content_hash(&self) -> [u8; 32];
}Expand description
Any type that can produce a deterministic content hash.
pub trait Hashable {
// Required method
fn content_hash(&self) -> [u8; 32];
}Any type that can produce a deterministic content hash.